==> zio-aws-appmesh_3-5.17.103.1-sources.jar: zio/aws/appmesh/model/GrpcGatewayRouteMetadata.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.HeaderName
import scala.jdk.CollectionConverters.*
final case class GrpcGatewayRouteMetadata(
    invert: Option[Boolean] = None,
    `match`: Option[zio.aws.appmesh.model.GrpcMetadataMatchMethod] = None,
    name: HeaderName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata = {
    import GrpcGatewayRouteMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
      .builder()
      .optionallyWith(invert.map(value => value: java.lang.Boolean))(_.invert)
      .optionallyWith(`match`.map(value => value.buildAwsValue()))(_.`match`)
      .name(HeaderName.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.GrpcGatewayRouteMetadata.ReadOnly =
    zio.aws.appmesh.model.GrpcGatewayRouteMetadata.wrap(buildAwsValue())
}
object GrpcGatewayRouteMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.GrpcGatewayRouteMetadata =
      zio.aws.appmesh.model.GrpcGatewayRouteMetadata(
        invert.map(value => value),
        `match`.map(value => value.asEditable),
        name
      )
    def invert: Option[Boolean]
    def `match`: Option[zio.aws.appmesh.model.GrpcMetadataMatchMethod.ReadOnly]
    def name: HeaderName
    def getInvert: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("invert", invert)
    def getMatch: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.GrpcMetadataMatchMethod.ReadOnly
    ] = AwsError.unwrapOptionField("match", `match`)
    def getName: ZIO[Any, Nothing, HeaderName] = ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
  ) extends zio.aws.appmesh.model.GrpcGatewayRouteMetadata.ReadOnly {
    override val invert: Option[Boolean] =
      scala.Option(impl.invert()).map(value => value: Boolean)
    override val `match`
        : Option[zio.aws.appmesh.model.GrpcMetadataMatchMethod.ReadOnly] = scala
      .Option(impl.`match`())
      .map(value => zio.aws.appmesh.model.GrpcMetadataMatchMethod.wrap(value))
    override val name: HeaderName =
      zio.aws.appmesh.model.primitives.HeaderName(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
  ): zio.aws.appmesh.model.GrpcGatewayRouteMetadata.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_3-5.17.195.2-sources.jar: zio/aws/appmesh/model/GrpcGatewayRouteMetadata.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.HeaderName
import scala.jdk.CollectionConverters.*
final case class GrpcGatewayRouteMetadata(
    invert: Optional[Boolean] = Optional.Absent,
    `match`: Optional[zio.aws.appmesh.model.GrpcMetadataMatchMethod] =
      Optional.Absent,
    name: HeaderName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata = {
    import GrpcGatewayRouteMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
      .builder()
      .optionallyWith(invert.map(value => value: java.lang.Boolean))(_.invert)
      .optionallyWith(`match`.map(value => value.buildAwsValue()))(_.`match`)
      .name(HeaderName.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.GrpcGatewayRouteMetadata.ReadOnly =
    zio.aws.appmesh.model.GrpcGatewayRouteMetadata.wrap(buildAwsValue())
}
object GrpcGatewayRouteMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.GrpcGatewayRouteMetadata =
      zio.aws.appmesh.model.GrpcGatewayRouteMetadata(
        invert.map(value => value),
        `match`.map(value => value.asEditable),
        name
      )
    def invert: Optional[Boolean]
    def `match`
        : Optional[zio.aws.appmesh.model.GrpcMetadataMatchMethod.ReadOnly]
    def name: HeaderName
    def getInvert: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("invert", invert)
    def getMatch: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.GrpcMetadataMatchMethod.ReadOnly
    ] = AwsError.unwrapOptionField("match", `match`)
    def getName: ZIO[Any, Nothing, HeaderName] = ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
  ) extends zio.aws.appmesh.model.GrpcGatewayRouteMetadata.ReadOnly {
    override val invert: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.invert())
      .map(value => value: Boolean)
    override val `match`
        : Optional[zio.aws.appmesh.model.GrpcMetadataMatchMethod.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`match`())
        .map(value => zio.aws.appmesh.model.GrpcMetadataMatchMethod.wrap(value))
    override val name: HeaderName =
      zio.aws.appmesh.model.primitives.HeaderName(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcGatewayRouteMetadata
  ): zio.aws.appmesh.model.GrpcGatewayRouteMetadata.ReadOnly = new Wrapper(impl)
}
